@@ -22,7 +22,7 @@ import sys
 
 from calculate.consolegui import qt
 from calculate.core.client.function import create_obj
-from calculate.lib.utils.files import readLinesFile, listDirectory
+from calculate.lib.utils.files import readLinesFile, listDirectory, readFile
 from PIL import Image
 from calculate.lib.utils.colortext.palette import (
     GuiPalette as WorkPalette)
@@ -2706,7 +2706,7 @@ def getRunProc():
         cmdLineFile = '/proc/%s/cmdline'%procNum
         try:
             if os.path.exists(cmdLineFile):
-                return [open(cmdLineFile,'r').read().strip(), procNum]
+                return [readFile(cmdLineFile).strip(), procNum]
         except:
             pass
         return ["", procNum]
